;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "simple-httpd" "1.6"
  "Pure Elisp HTTP server."
  '((emacs  "27.1")
    (compat "31"))
  :url "https://github.com/skeeto/emacs-http-server"
  :commit "5a9c69ae93ed5e2cdca98f51b41f6a6782091d74"
  :revdesc "1.6-0-g5a9c69ae93ed"
  :keywords '("network" "comm")
  :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
  :maintainers '(("Philip Kaludercic" . "philipk@posteo.net")
                 ("Daniel Mendler" . "mail@daniel-mendler.de")))
